@@ -3,7 +3,7 @@
 Standalone functions for running language models with full parameter typing.
 """
 
-from typing import Any, List, TypeVar, Union, Optional, Type, overload, Dict, TYPE_CHECKING
+from typing import Any, List, TypeVar, Union, Optional, Type, overload, Dict, TYPE_CHECKING, Callable
 from typing_extensions import Literal
 
 if TYPE_CHECKING:
@@ -152,8 +152,16 @@ def run_language_model(
     instructor_mode: Optional[LanguageModelInstructorMode] = "tool_call",
     response_field_name: Optional[str] = None,
     response_field_instruction: Optional[str] = None,
+    response_model_name: Optional[str] = None,
     max_retries: Optional[int] = None,
     strict: Optional[bool] = None,
+    validation_context: Optional[Dict[str, Any]] = None,
+    context: Optional[Dict[str, Any]] = None,
+    completion_kwargs_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_response_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_error_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_last_attempt_hooks: Optional[List[Callable[..., None]]] = None,
+    parse_error_hooks: Optional[List[Callable[..., None]]] = None,
     # Streaming settings
     stream: Literal[False] = False,
     stream_options: Optional[Dict[str, Any]] = None,
@@ -207,8 +215,16 @@ def run_language_model(
     instructor_mode: Optional[LanguageModelInstructorMode] = "tool_call",
     response_field_name: Optional[str] = None,
     response_field_instruction: Optional[str] = None,
+    response_model_name: Optional[str] = None,
     max_retries: Optional[int] = None,
     strict: Optional[bool] = None,
+    validation_context: Optional[Dict[str, Any]] = None,
+    context: Optional[Dict[str, Any]] = None,
+    completion_kwargs_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_response_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_error_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_last_attempt_hooks: Optional[List[Callable[..., None]]] = None,
+    parse_error_hooks: Optional[List[Callable[..., None]]] = None,
     # Streaming settings
     stream: Literal[True],
     stream_options: Optional[Dict[str, Any]] = None,
@@ -383,8 +399,16 @@ async def async_run_language_model(
     instructor_mode: Optional[LanguageModelInstructorMode] = "tool_call",
     response_field_name: Optional[str] = None,
     response_field_instruction: Optional[str] = None,
+    response_model_name: Optional[str] = None,
     max_retries: Optional[int] = None,
     strict: Optional[bool] = None,
+    validation_context: Optional[Dict[str, Any]] = None,
+    context: Optional[Dict[str, Any]] = None,
+    completion_kwargs_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_response_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_error_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_last_attempt_hooks: Optional[List[Callable[..., None]]] = None,
+    parse_error_hooks: Optional[List[Callable[..., None]]] = None,
     # Streaming settings
     stream: Literal[False] = False,
     stream_options: Optional[Dict[str, Any]] = None,
@@ -438,8 +462,16 @@ async def async_run_language_model(
     instructor_mode: Optional[LanguageModelInstructorMode] = "tool_call",
     response_field_name: Optional[str] = None,
     response_field_instruction: Optional[str] = None,
+    response_model_name: Optional[str] = None,
     max_retries: Optional[int] = None,
     strict: Optional[bool] = None,
+    validation_context: Optional[Dict[str, Any]] = None,
+    context: Optional[Dict[str, Any]] = None,
+    completion_kwargs_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_response_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_error_hooks: Optional[List[Callable[..., None]]] = None,
+    completion_last_attempt_hooks: Optional[List[Callable[..., None]]] = None,
+    parse_error_hooks: Optional[List[Callable[..., None]]] = None,
     # Streaming settings
     stream: Literal[True],
     stream_options: Optional[Dict[str, Any]] = None,
